"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var _1 = require(".");
var flags_1 = require("./flags");
describe("Generate io-ts validators", function () {
    test("generates validators for primitive types", function () {
        expect(_1.getValidatorsFromString("type num = number;")).toBe("const num = t.number");
        expect(_1.getValidatorsFromString("type str = string;")).toBe("const str = t.string");
        expect(_1.getValidatorsFromString("type nil = null;")).toBe("const nil = t.null");
    });
    test("generates validators for basic interfaces and object types", function () {
        var inputInterface = "\n    interface Test { foo: number, bar: string }\n  ";
        var inputObjectType = "\n    type Test = { foo: number, bar: string }\n  ";
        var result = "const Test = t.type({foo: t.number, bar: t.string})";
        expect(_1.getValidatorsFromString(inputInterface)).toBe(result);
        expect(_1.getValidatorsFromString(inputObjectType)).toBe(result);
    });
    test("generates validators for arrays", function () {
        expect(_1.getValidatorsFromString("type arr = string[]")).toBe("const arr = t.array(t.string)");
        expect(_1.getValidatorsFromString("type arr = Array<{foo: string}>")).toBe("const arr = t.array(t.type({foo: t.string}))");
    });
    test("generates validators for record types", function () {
        expect(_1.getValidatorsFromString("type rec = Record<number, string>")).toBe("const rec = t.record(t.number, t.string)");
        expect(_1.getValidatorsFromString("type rec = Record<string, null>")).toBe("const rec = t.record(t.string, t.null)");
    });
    test("generates validators for union types", function () {
        expect(_1.getValidatorsFromString("type un = string | number")).toBe("const un = t.union([t.string, t.number])");
        expect(_1.getValidatorsFromString("type un = string | number | { foo: string }")).toBe("const un = t.union([t.string, t.number, t.type({foo: t.string})])");
    });
    test("optimizes validator for string literal union types", function () {
        expect(_1.getValidatorsFromString("type un = 'foo' | 'bar'")).toBe('const un = t.keyof({"foo": null, "bar": null})');
    });
    test("generates validators for intersection types", function () {
        expect(_1.getValidatorsFromString("type inter = { foo: string } | { bar: number } | { foo: number }")).toBe("const inter = t.union([t.type({foo: t.string}), t.type({bar: t.number}), t.type({foo: t.number})])");
    });
    test("generates validators for function types", function () {
        expect(_1.getValidatorsFromString("type fn = () => void")).toBe("const fn = t.Function");
        expect(_1.getValidatorsFromString("type fn = (s: string, n: number) => (b: boolean) => object")).toBe("const fn = t.Function");
    });
    test("generates validators for literal types", function () {
        expect(_1.getValidatorsFromString('type foo = "foo"')).toBe('const foo = t.literal("foo")');
        expect(_1.getValidatorsFromString("type one = 1")).toBe("const one = t.literal(1)");
        expect(_1.getValidatorsFromString("type f = false")).toBe("const f = t.literal(false)");
    });
});
describe("Internals", function () {
    test("gets binary flags", function () {
        expect(flags_1.extractFlags(10)).toEqual([8, 2]);
        expect(flags_1.extractFlags(100)).toEqual([64, 32, 4]);
    });
});
//# sourceMappingURL=index.spec.js.map