"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ts = require("typescript");
var flags_1 = require("./flags");
function isObjectType(type) {
    return flags_1.extractFlags(type.flags).includes(ts.TypeFlags.Object);
}
exports.isObjectType = isObjectType;
function isPrimitiveType(type) {
    return flags_1.extractFlags(type.flags).some(function (flag) {
        return [
            ts.TypeFlags.String,
            ts.TypeFlags.Number,
            ts.TypeFlags.Boolean,
            ts.TypeFlags.Null
        ].includes(flag);
    });
}
exports.isPrimitiveType = isPrimitiveType;
function isAnyOrUnknown(type) {
    return flags_1.extractFlags(type.flags).some(function (f) {
        return [ts.TypeFlags.Any, ts.TypeFlags.Unknown].includes(f);
    });
}
exports.isAnyOrUnknown = isAnyOrUnknown;
function isVoid(type) {
    return flags_1.extractFlags(type.flags).includes(ts.TypeFlags.Void);
}
exports.isVoid = isVoid;
function isTupleType(type, checker) {
    var node = checker.typeToTypeNode(type);
    return ts.isTupleTypeNode(node);
}
exports.isTupleType = isTupleType;
function isRecordType(type) {
    return type.aliasSymbol && type.aliasSymbol.escapedName === "Record";
}
exports.isRecordType = isRecordType;
function isStringIndexedObjectType(type) {
    return type.getStringIndexType();
}
exports.isStringIndexedObjectType = isStringIndexedObjectType;
function isNumberIndexedType(type) {
    return type.getNumberIndexType();
}
exports.isNumberIndexedType = isNumberIndexedType;
function isArrayType(type, checker) {
    var node = checker.typeToTypeNode(type);
    return ts.isArrayTypeNode(node);
}
exports.isArrayType = isArrayType;
function isFunctionType(type) {
    return !!type.getCallSignatures().length;
}
exports.isFunctionType = isFunctionType;
function isBasicObjectType(type, checker) {
    return checker.typeToString(type) === "object";
}
exports.isBasicObjectType = isBasicObjectType;
function isLiteralType(type) {
    return flags_1.extractFlags(type.flags).some(function (f) {
        return [
            ts.TypeFlags.StringLiteral,
            ts.TypeFlags.NumberLiteral,
            ts.TypeFlags.BooleanLiteral
        ].includes(f);
    });
}
exports.isLiteralType = isLiteralType;
//# sourceMappingURL=type.js.map